%This estimates the revised model in Section 5.4.2 using the post sample of
%data. It requires the data file Section5_4_2.csv, which is made by
%TransformData.do. It saves the results in Section542results.mat

clear all
global weightmat fulldata nHH fspace model R villsize villY
R=0.11;
count=1;
%first load in data
fulldata=load('Section5_4_2data.csv');
fulldata(fulldata(:,8)==1,8)=0;
fulldata(fulldata(:,9)==1,9)=0;
fulldata(fulldata(:,10)==1,10)=0;
fulldata(fulldata(:,11)==1,11)=0;
fulldata(fulldata(:,12)==1,12)=0;
fulldata(fulldata(:,13)==1,13)=0;
fulldata(fulldata(:,14)==1,14)=0;
nHH=length(fulldata(:,1));

%initialize weighting matrix
weightmat=eye(27);

%initialize upper bound, lower bound and seed values for
%[r G VarN Varu slbarbase slbarshift slbarcon slbarHH clbar beta rho Eistar  Varistar VarErr] 
thetahat=[0.0559    1.0521    0.1681    0.2647   -0.0895   -0.0991  -44.5912   -1.1532    0.5063    0.9257    1.1490    1.4175    6.4379    0.0895];
thetamin=[0.01    1.01    0.01  0.01  -0.5 -0.5 -100 -5  0.01    0.90    1.01    1    0.5    0.001];
thetamax=[0.09    1.09    0.5  0.7  -0.02 -0.01 -1 -0.05  0.8    0.97    1.5    7    7.5    0.85];
%thetamin=[0.045    1.035    0.01  0.01  -0.15 -0.18 -81 -1.35  0.48    0.92    1.01    1    5.5024    0.001];
%thetamax=[0.064    1.06    0.5  0.7  -0.04 -0.03 -20 -1.05  0.56    0.93    1.5    1.7    7.5    0.15];


[J thetahat]=solveGMMsimplexlevelsrandjustpost(thetahat,thetamin,thetamax);

weightmatold=weightmat;
u=separatemomentslevels_justpostyears(thetahat);
omega=1/nHH*u'*u;
weightmat=inv(omega);


%calculate numerical derivatives and gamma
gamma=zeros(27,14);
dfdtheta1=(separatemomentslevels_justpostyears([thetahat(1)+0.001 thetahat(2:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1)-0.001 thetahat(2:14)]))/(0.002);
gamma(:,1)=1/nHH*sum(dfdtheta1)';        
dfdtheta2=(separatemomentslevels_justpostyears([thetahat(1) thetahat(2)+0.001 thetahat(3:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1) thetahat(2)-0.001 thetahat(3:14)]))/(0.002);
gamma(:,2)=1/nHH*sum(dfdtheta2)';        
dfdtheta3=(separatemomentslevels_justpostyears([thetahat(1:2) thetahat(3)+0.001 thetahat(4:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:2) thetahat(3)-0.001 thetahat(4:14)]))/(0.002);
gamma(:,3)=1/nHH*sum(dfdtheta3)';        
dfdtheta4=(separatemomentslevels_justpostyears([thetahat(1:3) thetahat(4)+0.001 thetahat(5:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:3) thetahat(4)-0.001 thetahat(5:14)]))/(0.002);
gamma(:,4)=1/nHH*sum(dfdtheta4)';        
dfdtheta5=(separatemomentslevels_justpostyears([thetahat(1:4) thetahat(5)+0.001 thetahat(6:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:4) thetahat(5)-0.001 thetahat(6:14)]))/(0.002);
gamma(:,5)=1/nHH*sum(dfdtheta5)';        
dfdtheta6=(separatemomentslevels_justpostyears([thetahat(1:5) thetahat(6)+0.001 thetahat(7:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:5) thetahat(6)-0.001 thetahat(7:14)]))/(0.002);
gamma(:,6)=1/nHH*sum(dfdtheta6)';        
dfdtheta7=(separatemomentslevels_justpostyears([thetahat(1:6) thetahat(7)+0.001 thetahat(8:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:6) thetahat(7)-0.001 thetahat(8:14)]))/(0.002);
gamma(:,7)=1/nHH*sum(dfdtheta7)';        
dfdtheta8=(separatemomentslevels_justpostyears([thetahat(1:7) thetahat(8)+0.001 thetahat(9:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:7) thetahat(8)-0.001 thetahat(9:14)]))/(0.002);
gamma(:,8)=1/nHH*sum(dfdtheta8)';        
dfdtheta9=(separatemomentslevels_justpostyears([thetahat(1:8) thetahat(9)+0.001 thetahat(10:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:8) thetahat(9)-0.001 thetahat(10:14)]))/(0.002);
gamma(:,9)=1/nHH*sum(dfdtheta9)';        
dfdtheta10=(separatemomentslevels_justpostyears([thetahat(1:9) thetahat(10)+0.001 thetahat(11:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:9) thetahat(10)-0.001 thetahat(11:14)]))/(0.002);
gamma(:,10)=1/nHH*sum(dfdtheta10)';        
dfdtheta11=(separatemomentslevels_justpostyears([thetahat(1:10) thetahat(11)+0.001 thetahat(12:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:10) thetahat(11)-0.001 thetahat(12:14)]))/(0.002);
gamma(:,11)=1/nHH*sum(dfdtheta11)';        
dfdtheta12=(separatemomentslevels_justpostyears([thetahat(1:11) thetahat(12)+0.001 thetahat(13:14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:11) thetahat(12)-0.001 thetahat(13:14)]))/(0.002);
gamma(:,12)=1/nHH*sum(dfdtheta12)';        
dfdtheta13=(separatemomentslevels_justpostyears([thetahat(1:12) thetahat(13)+0.001 thetahat(14)])- ...
         separatemomentslevels_justpostyears([thetahat(1:12) thetahat(13)-0.001 thetahat(14)]))/(0.002);
gamma(:,13)=1/nHH*sum(dfdtheta13)';        
dfdtheta14=(separatemomentslevels_justpostyears([thetahat(1:13) thetahat(14)+0.001])- ...
         separatemomentslevels_justpostyears([thetahat(1:13) thetahat(14)-0.001]))/(0.002);
gamma(:,14)=1/nHH*sum(dfdtheta14)';        
      
eps=separatemomentslevels_justpostyears(thetahat);

covar=inv(gamma'*weightmat*gamma);

diary Section542results.txt;
thetahat=thetahat
for jj=1:64
    slbarmb(jj)=thetahat(6)+thetahat(7)*mean(fulldata(fulldata(:,57)==jj,58))^thetahat(8);
end
avgconstraint=mean(slbarmb)
stdevconstraint=std(slbarmb)
maxconstraint=max(slbarmb)
minconstraint=min(slbarmb)
diary off;

save Section542results
