%This computes the estimation results for R=0.04 in Section 5.4.1.  
%It uses data from 'Table3data.csv'.
 
clear all
global predata weightmat nHH R model
R=0.04;
count=1;
%first load in data
predata=load('Table3data.csv');
%replace ones with zeros.  Ones were used in the data because it is easier
%when taking logs
predata(predata(:,6)==1,6)=0;
predata(predata(:,7)==1,7)=0;
predata(predata(:,8)==1,8)=0;
predata(predata(:,9)==1,9)=0;
predata(predata(:,10)==1,10)=0;
nHH=length(predata(:,1));

%initialize weighting matrix
weightmat=eye(16);

%initialize upper bound, lower bound and seed values for
%[r G VarN Varu slbar clbar beta rho Eistar Varistar]
thetahat=[0.0176    1.0345    0.0200    0.0579   -0.0400    0.5588    0.9677    1.1039    0.4000    2.7000    0.0246];
thetamin=[0.01 1.02 0.01  0.04 -0.1  0.45 0.95 1.07 0.2 2 0.001]; 
thetamax=[0.04 1.06 0.05 0.12 -0.02 0.65 0.98 1.13 3.4 7.8 0.05];

%perform estimation
[J2 thetahat]=solveGMMsimplexlevelsrand(thetahat,thetamin,thetamax);
u=separatemomentslevels(thetahat);
omega=1/nHH*u'*u;
weightmat=inv(omega);

%calculate numerical derivatives and gamma
gamma=zeros(16,11);
dfdtheta1=(separatemomentslevels([thetahat(1)+0.001 thetahat(2:11)])- ...
         separatemomentslevels([thetahat(1)-0.001 thetahat(2:11)]))/(0.002);
gamma(:,1)=1/nHH*sum(dfdtheta1)';        
dfdtheta2=(separatemomentslevels([thetahat(1) thetahat(2)+0.001 thetahat(3:11)])- ...
         separatemomentslevels([thetahat(1) thetahat(2)-0.001 thetahat(3:11)]))/(0.002);
gamma(:,2)=1/nHH*sum(dfdtheta2)';        
dfdtheta3=(separatemomentslevels([thetahat(1:2) thetahat(3)+0.001 thetahat(4:11)])- ...
         separatemomentslevels([thetahat(1:2) thetahat(3)-0.001 thetahat(4:11)]))/(0.002);
gamma(:,3)=1/nHH*sum(dfdtheta3)';        
dfdtheta4=(separatemomentslevels([thetahat(1:3) thetahat(4)+0.001 thetahat(5:11)])- ...
         separatemomentslevels([thetahat(1:3) thetahat(4)-0.001 thetahat(5:11)]))/(0.002);
gamma(:,4)=1/nHH*sum(dfdtheta4)';        
dfdtheta5=(separatemomentslevels([thetahat(1:4) thetahat(5)+0.001 thetahat(6:11)])- ...
         separatemomentslevels([thetahat(1:4) thetahat(5)-0.001 thetahat(6:11)]))/(0.002);
gamma(:,5)=1/nHH*sum(dfdtheta5)';        
dfdtheta6=(separatemomentslevels([thetahat(1:5) thetahat(6)+0.001 thetahat(7:11)])- ...
         separatemomentslevels([thetahat(1:5) thetahat(6)-0.001 thetahat(7:11)]))/(0.002);
gamma(:,6)=1/nHH*sum(dfdtheta6)';        
dfdtheta7=(separatemomentslevels([thetahat(1:6) thetahat(7)+0.001 thetahat(8:11)])- ...
         separatemomentslevels([thetahat(1:6) thetahat(7)-0.001 thetahat(8:11)]))/(0.002);
gamma(:,7)=1/nHH*sum(dfdtheta7)';        
dfdtheta8=(separatemomentslevels([thetahat(1:7) thetahat(8)+0.001 thetahat(9:11)])- ...
         separatemomentslevels([thetahat(1:7) thetahat(8)-0.001 thetahat(9:11)]))/(0.002);
gamma(:,8)=1/nHH*sum(dfdtheta8)';        
dfdtheta9=(separatemomentslevels([thetahat(1:8) thetahat(9)+0.001 thetahat(10:11)])- ...
         separatemomentslevels([thetahat(1:8) thetahat(9)-0.001 thetahat(10:11)]))/(0.002);
gamma(:,9)=1/nHH*sum(dfdtheta9)';        
dfdtheta10=(separatemomentslevels([thetahat(1:9) thetahat(10)+0.001 thetahat(11)])- ...
         separatemomentslevels([thetahat(1:9) thetahat(10)-0.001 thetahat(11)]))/(0.002);
gamma(:,10)=1/nHH*sum(dfdtheta10)';        
dfdtheta11=(separatemomentslevels([thetahat(1:10) thetahat(11)+0.001 ])- ...
         separatemomentslevels([thetahat(1:10) thetahat(11)-0.001]))/(0.002);
gamma(:,11)=1/nHH*sum(dfdtheta11)';        
      

covar=inv(gamma'*weightmat*gamma);

%save results for Section 5.4.1 with R=0.04 -- variances need to be transformed into standard
%deviations
diary Section5_4_1_R04;
R=R
thetahat=thetahat
stddevs=sqrt(diag(covar))/sqrt(nHH)
rawresids=sum(u)/nHH;
weightedresids=rawresids*sqrtm(weightmat)
J=weightedresids*weightedresids'
averages=averagesout(thetahat)
diary off;


%write estimates as text file
dlmwrite('thetahat_R04.csv',thetahat);

%save all results
save millbaht_R04;
