%This computes the results in Tables 3 and 4.  It requires the compecon
%toolbox of Miranda and Fackler, available at
%http://www4.ncsu.edu/~pfackler/compecon/
%It uses data from 'Table3data.csv'.
%It calls the following subroutines: solveGMMsimplexlevelsrand.m, separatemomentlevels.m, and averagesout.m
%It produces the following output files: Table3, Table4, thetahat_R11.csv, millbaht_R11.mat 

!del Table3
!del Table4

clear all
global predata weightmat nHH R model
R=0.11;
count=1;
%first load in data
predata=load('Table3data.csv');
%replace ones with zeros.  Ones were used in the data because it is easier
%when taking logs
predata(predata(:,6)==1,6)=0;
predata(predata(:,7)==1,7)=0;
predata(predata(:,8)==1,8)=0;
predata(predata(:,9)==1,9)=0;
predata(predata(:,10)==1,10)=0;
nHH=length(predata(:,1));

%initialize weighting matrix
weightmat=eye(16);

%initialize upper bound, lower bound and seed values for
%[r G VarN Varu slbar clbar beta rho Eistar Varistar]
thetahat=[0.05428	1.0465	0.097655	0.17874	-0.082464	0.52107	0.92569	1.1984	1.4663	6.2612	0.022375];
thetamin=[0.053 1.042 0.08  0.16 -0.10  0.48 0.92 1.17 1.1 5 0.001]; 
thetamax=[0.058 1.048 0.11 0.22 -0.06 0.56 0.935 1.22 1.9 7.5 0.05];

%perform estimation
[J thetahat]=solveGMMsimplexlevelsrand(thetahat,thetamin,thetamax);
u=separatemomentslevels(thetahat);
omega=1/nHH*u'*u;
weightmat=inv(omega);

%calculate numerical derivatives and gamma
gamma=zeros(16,11);
dfdtheta1=(separatemomentslevels([thetahat(1)+0.001 thetahat(2:11)])- ...
         separatemomentslevels([thetahat(1)-0.001 thetahat(2:11)]))/(0.002);
gamma(:,1)=1/nHH*sum(dfdtheta1)';        
dfdtheta2=(separatemomentslevels([thetahat(1) thetahat(2)+0.001 thetahat(3:11)])- ...
         separatemomentslevels([thetahat(1) thetahat(2)-0.001 thetahat(3:11)]))/(0.002);
gamma(:,2)=1/nHH*sum(dfdtheta2)';        
dfdtheta3=(separatemomentslevels([thetahat(1:2) thetahat(3)+0.001 thetahat(4:11)])- ...
         separatemomentslevels([thetahat(1:2) thetahat(3)-0.001 thetahat(4:11)]))/(0.002);
gamma(:,3)=1/nHH*sum(dfdtheta3)';        
dfdtheta4=(separatemomentslevels([thetahat(1:3) thetahat(4)+0.001 thetahat(5:11)])- ...
         separatemomentslevels([thetahat(1:3) thetahat(4)-0.001 thetahat(5:11)]))/(0.002);
gamma(:,4)=1/nHH*sum(dfdtheta4)';        
dfdtheta5=(separatemomentslevels([thetahat(1:4) thetahat(5)+0.001 thetahat(6:11)])- ...
         separatemomentslevels([thetahat(1:4) thetahat(5)-0.001 thetahat(6:11)]))/(0.002);
gamma(:,5)=1/nHH*sum(dfdtheta5)';        
dfdtheta6=(separatemomentslevels([thetahat(1:5) thetahat(6)+0.001 thetahat(7:11)])- ...
         separatemomentslevels([thetahat(1:5) thetahat(6)-0.001 thetahat(7:11)]))/(0.002);
gamma(:,6)=1/nHH*sum(dfdtheta6)';        
dfdtheta7=(separatemomentslevels([thetahat(1:6) thetahat(7)+0.001 thetahat(8:11)])- ...
         separatemomentslevels([thetahat(1:6) thetahat(7)-0.001 thetahat(8:11)]))/(0.002);
gamma(:,7)=1/nHH*sum(dfdtheta7)';        
dfdtheta8=(separatemomentslevels([thetahat(1:7) thetahat(8)+0.001 thetahat(9:11)])- ...
         separatemomentslevels([thetahat(1:7) thetahat(8)-0.001 thetahat(9:11)]))/(0.002);
gamma(:,8)=1/nHH*sum(dfdtheta8)';        
dfdtheta9=(separatemomentslevels([thetahat(1:8) thetahat(9)+0.001 thetahat(10:11)])- ...
         separatemomentslevels([thetahat(1:8) thetahat(9)-0.001 thetahat(10:11)]))/(0.002);
gamma(:,9)=1/nHH*sum(dfdtheta9)';        
dfdtheta10=(separatemomentslevels([thetahat(1:9) thetahat(10)+0.001 thetahat(11)])- ...
         separatemomentslevels([thetahat(1:9) thetahat(10)-0.001 thetahat(11)]))/(0.002);
gamma(:,10)=1/nHH*sum(dfdtheta10)';        
dfdtheta11=(separatemomentslevels([thetahat(1:10) thetahat(11)+0.001 ])- ...
         separatemomentslevels([thetahat(1:10) thetahat(11)-0.001]))/(0.002);
gamma(:,11)=1/nHH*sum(dfdtheta11)';        
      

covar=inv(gamma'*weightmat*gamma);

%save results for Table 3 -- variances need to be transformed into standard
%deviations
diary Table3;
R=R
thetahat=thetahat
stddevs=sqrt(diag(covar))/sqrt(nHH)
%J=J
rawresids=sum(u)/nHH;
weightedresids=rawresids*sqrtm(weightmat)
J=weightedresids*weightedresids'
averages=averagesout(thetahat);
averageC=averages(1:2)
averageD=averages(3:4)
averageI=averages(5:6)
averageDEF=averages(7:8)
averageYgrowth=averages(9:10)

diary off;

%save results for Table 4
diary Table4;
fortable4=gamma
diary off;

%write estimates as text file
dlmwrite('thetahat_R11.csv',thetahat);

%save all results
save millbaht_R11;
