%This subroutine calculates the individual moments for each household.  It requires the compecon
%toolbox of Miranda and Fackler, available at
%http://www4.ncsu.edu/~pfackler/compecon/.  
%It calls the subroutine
%solvepolicy.m, It requires the parameter vector theta and outputs eps, 
%which is a vector of empirical moment deviations for each of nHH households and 16 moments

function [eps] = separatemomentslevels(theta)
tic

global predata weightmat nHH fspace model R
%assign parameter values
model.r=1+real(theta(1));
model.G=real(theta(2));
model.VarN=real(theta(3));
model.Varu=real(theta(4));
model.slbar=real(theta(5));
model.clbar=real(theta(6));
model.beta=real(theta(7));
model.rho=real(theta(8));
model.Eistar=real(theta(9));
model.Varistar=real(theta(10));
model.VarErr=real(theta(11));
model.R=R;
d=4;

%set other parameters of the model
model.maxit=300;  model.tol=0.0001;
model.dN=4;
model.du=4;
model.di=8;        % number of i points for Gaussian quadrature integration
model.di2=model.di+1;
[model.e, model.w]=qnwlogn([model.dN,model.du,model.di],[0 0 model.Eistar],[model.VarN 0 0; 0 model.Varu 0; 0 0 model.Varistar]);
[model.istarvals, istarweight]=qnwlogn(model.di,model.Eistar,model.Varistar);

%discretize the random shocks e=[N,u,istar], VarN should be 0.26, varu should be 0.36

model.N=model.e(:,1);
model.u=model.e(:,2);
model.istar=model.e(:,3);
model.istarvals2=[0;model.istarvals];
model.di2=length(model.istarvals2);
model.lmax=max(predata(:,3)./predata(:,2))*model.e(end,2);

%get weights and values for u and istar for expectation calculations
[Sval,Sw]=qnwlogn([d d d],[0 model.Eistar 0],[model.Varu 0 0; 0 model.Varistar 0; 0 0 model.VarErr]);
ds=length(Sw);
S=200;


%initialize size of vectors for moment calculations below
eps=zeros(nHH,16);
def=zeros(nHH,1);
iable=zeros(nHH,1);
d=zeros(nHH,5,ds);
Clevel=zeros(nHH,5,ds);
dIlevel=zeros(nHH,5,ds);
EClev=zeros(nHH,5);
Ed=zeros(nHH,5);
EdIlev=zeros(nHH,5);
dp=zeros(nHH,1);
s=zeros(nHH,1);
C=zeros(nHH,1);
Yprime=ones(nHH,4,S);
Y2prime=ones(nHH,3,S);
Y3prime=ones(nHH,2,S);
Lprime=zeros(nHH,S);
L2prime=zeros(nHH,S);
ElnYp=zeros(nHH,4);
ElnY2p=zeros(nHH,3);
ElnY2p=zeros(nHH,2);
sqdevlnYp=zeros(nHH,4,S);
sqdevlnY2p=zeros(nHH,3,S);
sqdevlnY3p=zeros(nHH,2,S);
EvarlnYp=zeros(nHH,4);
EvarlnY2p=zeros(nHH,3);
EvarlnY3p=zeros(nHH,2);

%now get vectors we will need for calculations
zs=zeros(nHH,1);
os=ones(nHH,1);

%next we solve for the policy function using theta
[c ccons lccons]=solvepolicy(model);
if length(c)==1
    eps=ones(nHH,16)*10000000;
else
    
    %we'll leave data in matrix form for routines, but use this as a key:
    % Y1=predata(:,1);
    % Y2=predata(:,2);
    % Y3=predata(:,3);
    % Y4=predata(:,4);
    % Y5=predata(:,5);
    % I1=predata(:,6);
    % I2=predata(:,7);
    % I3=predata(:,8);
    % I4=predata(:,9);
    % I5=predata(:,10);
    % INT2=predata(:,11);
    % INT3=predata(:,12);
    % INT4=predata(:,13);
    % INT5=predata(:,14);
    % S1=predata(:,15);
    % S2=predata(:,16);
    % S3=predata(:,17);
    % S4=predata(:,18);
    % STINT2=predata(:,19);
    % STINT3=predata(:,20);
    % STINT4=predata(:,21);
    % STINT5=predata(:,22);
    % ST1=predata(:,23);
    % ST2=predata(:,24);
    % ST3=predata(:,25);
    % ST4=predata(:,26);
    % DEF2=predata(:,27);
    % DEF3=predata(:,28);
    % DEF4=predata(:,29);
    % DEF5=predata(:,30);
    % L2=predata(:,31);
    % L3=predata(:,32);
    % L4=predata(:,33);
    % L5=predata(:,34);
    % C2=predata(:,35);
    % C3=predata(:,36);
    % C4=predata(:,37);
    % C5=predata(:,38);
    
    Ns=exp(model.VarN^0.5*randn(nHH,S,3));
    Us=exp(model.Varu^0.5*randn(nHH,S,4));
    Errs=exp(model.VarErr^0.5*randn(nHH,S,5));
    istars=exp(model.Varistar^0.5*randn(nHH,S,3)+model.Eistar);
    
    
    for t=2:5
        %let's calculate current investment decisions, investment, and consumption conditional on current shocks
        for j=1:ds
            ya=predata(:,t)/Sval(j,3);
            la=(predata(:,29+t)-predata(:,t))+ya;
            def=(la./ya*Sval(j,1)<(model.slbar+model.clbar));
            iable=(la./ya*Sval(j,1)>model.slbar+model.clbar+Sval(j,2));
            %do for defaulters  (just need consumption)
            if max(def)==1
                Clevel(def==1,t,j)=model.clbar*ya(def==1)/Sval(j,1);
                d(def==1,t,j)=0;
            end
            %do for non-investors
            if max(iable==0 & def==0)==1
                d(iable==0 & def==0,t,j)=0;
                Clevel(iable==0 & def==0,t,j)=funeval(ccons,fspace,[(la(iable==0 & def==0)./ya(iable==0 & def==0)*Sval(j,1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==0 & def==0,1)]).*ya(iable==0 & def==0)/Sval(j,1);
            end
            %do for potential investors
            if max(iable)==1
                [valfun d(iable==1,t,j)]=max([funeval(c,fspace,[(la(iable==1)./ya(iable==1)*Sval(j,1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) funeval(c,fspace,[(la(iable==1)./ya(iable==1)*Sval(j,1)-model.slbar-model.clbar+0.01-Sval(j,2)).^(1-model.rho)/(1-model.rho)  Sval(j,2)*os(iable==1)])],[],2);
                d(iable==1,t,j)=d(iable==1,t,j)-1;
                Clevel(iable==1,t,j)=((1-d(iable==1,t,j)).*funeval(ccons,fspace,[(la(iable==1)./ya(iable==1)*Sval(j,1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) + d(iable==1,t,j).*funeval(ccons,fspace,[(la(iable==1)./ya(iable==1)*Sval(j,1)-model.slbar-model.clbar+0.01-Sval(j,2)).^(1-model.rho)/(1-model.rho)  Sval(j,2)*os(iable==1)])).*ya(iable==1)/Sval(j,1);
            end
            %now calculate log investment and investment levels
            dIlevel(:,t,j)=d(:,t,j).*(Sval(j,2)*ya(:)/Sval(j,1));
            EClev(:,t)=EClev(:,t)+Clevel(:,t,j)*Sw(j);
            Ed(:,t)=Ed(:,t)+d(:,t,j)*Sw(j);
            EdIlev(:,t)=EdIlev(:,t)+dIlevel(:,t,j)*Sw(j);
        end
        if t<=4
            for k=1:S
                ya=predata(:,t)./Errs(:,k,t-1);
                la=(predata(:,29+t)-predata(:,t))+ya;
                def=(la./ya.*Us(:,k,t-1)<(model.slbar+model.clbar));
                iable=(la./ya.*Us(:,k,t-1)>model.slbar+model.clbar+istars(:,k,t-1));
                %do for defaulters  (just need consumption)
                if max(def)==1
                    dp(def==1)=0;
                    C(def==1)=model.clbar*ya(def==1)./Us(def==1,k,t-1);
                    s(def==1)=model.slbar*ya(def==1)./Us(def==1,k,t-1);
                end
                %do for non-investors
                if max(iable==0 & def==0)==1
                    dp(iable==0 & def==0)=0;
                    C(iable==0 & def==0)=funeval(ccons,fspace,[(la(iable==0 & def==0)./ya(iable==0 & def==0).*Us(iable==0 & def==0,k,t-1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==0 & def==0,1)]).*ya(iable==0 & def==0)./Us(iable==0 & def==0,k,t-1);
                    s(iable==0 & def==0)=la(iable==0 & def==0)-C(iable==0 & def==0);
                end
                %do for potential investors
                if max(iable)==1
                    [valfun dp(iable==1)]=max([funeval(c,fspace,[(la(iable==1)./ya(iable==1).*Us(iable==1,k,t-1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) funeval(c,fspace,[(la(iable==1)./ya(iable==1).*Us(iable==1,k,t-1)-model.slbar-model.clbar+0.01-istars(iable==1,k,t-1)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t-1)])],[],2);
                    dp(iable==1)=dp(iable==1)-1;
                    C(iable==1)=((1-dp(iable==1)).*funeval(ccons,fspace,[(la(iable==1)./ya(iable==1).*Us(iable==1,k,t-1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) + dp(iable==1).*funeval(ccons,fspace,[(la(iable==1)./ya(iable==1).*Us(iable==1,k,t-1)-model.slbar-model.clbar+0.01-istars(iable==1,k,t-1)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t-1)])).*ya(iable==1)./Us(iable==1,k,t-1);
                    s(iable==1)=la(iable==1)-C(iable==1)-dp(iable==1).*istars(iable==1,k,t-1).*ya(iable==1)./Us(iable==1,k,t-1);
                end
                Yprime(:,t,k)=(model.G*Ns(:,k,t-1)+model.R*dp.*istars(:,k,t-1)).*ya.*Us(:,k,t)./Us(:,k,t-1).*Errs(:,k,t);
                Lprime(:,k)=s.*model.r+Yprime(:,t,k)./Errs(:,k,t);
            end
            if t<=3
                for k=1:S
                    ya=Yprime(:,t,k)./Errs(:,k,t);
                    def=(Lprime(:,k)./ya.*Us(:,k,t)<(model.slbar+model.clbar));
                    iable=(Lprime(:,k)./ya.*Us(:,k,t)>model.slbar+model.clbar+istars(:,k,t));
                    %do for defaulters  (just need consumption)
                    if max(def)==1
                        dp(def==1)=0;
                        C(def==1)=model.clbar*ya(def==1)./Us(def==1,k,t);
                        s(def==1)=model.slbar*ya(def==1)./Us(def==1,k,t);
                    end
                    %do for non-investors
                    if max(iable==0 & def==0)==1
                        dp(iable==0 & def==0)=0;
                        C(iable==0 & def==0)=funeval(ccons,fspace,[(Lprime(iable==0 & def==0,k)./ya(iable==0 & def==0).*Us(iable==0 & def==0,k,t)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==0 & def==0,1)]).*ya(iable==0 & def==0)./Us(iable==0 & def==0,k,t);
                        s(iable==0 & def==0)=Lprime(iable==0 & def==0,k)-C(iable==0 & def==0);
                    end
                    %do for potential investors
                    if max(iable)==1
                        [valfun dp(iable==1)]=max([funeval(c,fspace,[(Lprime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) funeval(c,fspace,[(Lprime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t)-model.slbar-model.clbar+0.01-istars(iable==1,k,t)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t)])],[],2);
                        dp(iable==1)=dp(iable==1)-1;
                        C(iable==1)=((1-dp(iable==1)).*funeval(ccons,fspace,[(Lprime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) + dp(iable==1).*funeval(ccons,fspace,[(Lprime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t)-model.slbar-model.clbar+0.01-istars(iable==1,k,t)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t)])).*ya(iable==1)./Us(iable==1,k,t);
                        s(iable==1)=Lprime(iable==1,k)-C(iable==1)-dp(iable==1).*istars(iable==1,k,t).*ya(iable==1)./Us(iable==1,k,t);
                    end
                    %now calculate income growth
                    Y2prime(:,t,k)=(model.G*Ns(:,k,t)+model.R*dp.*istars(:,k,t)).*ya.*Us(:,k,t+1)./Us(:,k,t).*Errs(:,k,t+1);
                    L2prime(:,k)=s.*model.r+Y2prime(:,t,k)./Errs(:,k,t+1);
                end
                if t<=2
                    for k=1:S
                        ya=Y2prime(:,t,k)./Errs(:,k,t+1);
                        def=(L2prime(:,k)./ya.*Us(:,k,t+1)<(model.slbar+model.clbar));
                        iable=(L2prime(:,k)./ya.*Us(:,k,t+1)>model.slbar+model.clbar+istars(:,k,t+1));
                        %do for defaulters  (just need consumption)
                        if max(def)==1
                            dp(def==1)=0;
                            C(def==1)=model.clbar*ya(def==1)./Us(def==1,k,t+1);
                        end
                        %do for non-investors
                        if max(iable==0 & def==0)==1
                            dp(iable==0 & def==0)=0;
                            C(iable==0 & def==0)=funeval(ccons,fspace,[(L2prime(iable==0 & def==0,k)./ya(iable==0 & def==0).*Us(iable==0 & def==0,k,t+1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==0 & def==0,1)]).*ya(iable==0 & def==0)./Us(iable==0 & def==0,k,t+1);
                        end
                        %do for potential investors
                        if max(iable)==1
                            [valfun dp(iable==1)]=max([funeval(c,fspace,[(L2prime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t+1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) funeval(c,fspace,[(L2prime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t+1)-model.slbar-model.clbar+0.01-istars(iable==1,k,t+1)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t+1)])],[],2);
                            dp(iable==1)=dp(iable==1)-1;
                            C(iable==1)=((1-dp(iable==1)).*funeval(ccons,fspace,[(L2prime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t+1)-model.slbar-model.clbar+0.01).^(1-model.rho)/(1-model.rho)  zs(iable==1,1)]) + dp(iable==1).*funeval(ccons,fspace,[(L2prime(iable==1,k)./ya(iable==1).*Us(iable==1,k,t+1)-model.slbar-model.clbar+0.01-istars(iable==1,k,t+1)).^(1-model.rho)/(1-model.rho)  istars(iable==1,k,t+1)])).*ya(iable==1)./Us(iable==1,k,t+1);
                        end
                        %now calculate income growth
                        Y3prime(:,t,k)=(model.G*Ns(:,k,t+1)+model.R*dp.*istars(:,k,t+1)).*ya.*Us(:,k,t+2)./Us(:,k,t+1).*Errs(:,k,t+2);
                    end
                end
            end
        end
    end
    ElnYp=mean(log(Yprime),3);
    ElnY2p=mean(log(Y2prime),3);
    ElnY3p=mean(log(Y3prime),3);
    for k=1:S
        sqdevlnYp(:,:,k)=(log(Yprime(:,:,k))-ElnYp).^2;
        sqdevlnY2p(:,:,k)=(log(Y2prime(:,:,k))-ElnY2p).^2;
        sqdevlnY3p(:,:,k)=(log(Y3prime(:,:,k))-ElnY3p).^2;
    end
    EvarlnYp=mean(sqdevlnYp,3);
    EvarlnY2p=mean(sqdevlnY2p,3);
    EvarlnY3p=mean(sqdevlnY3p,3);
    
    
    
    eps(:,1)=sum((predata(:,11:14)-(model.r-1)*(predata(:,15:18))),2);   %savings interest moment
    eps(:,2)=sum((predata(:,19:22)-(model.r-1)*(predata(:,23:26))),2);   %credit interest moment
    eps(:,3)=sum((log(predata(:,3:5))-ElnYp(:,2:4)),2);  %1-year growth expectation
    
    
    %construct relevant one-year data for remaining moments
    for t=2:5
        if t<5
            devYvar1(:,t)=(log(predata(:,t+1))-ElnYp(:,t)+mean(log(predata(:,t+1))-ElnYp(:,t))).^2-EvarlnYp(:,t);  %1-year growth variance
            if t<4
                devYvar2(:,t)=(log(predata(:,t+2))-ElnY2p(:,t)+mean(log(predata(:,t+2))-ElnY2p(:,t))).^2-EvarlnY2p(:,t);  %2-year growth variance
                if t<3
                    devYvar3(:,t)=(log(predata(:,t+3))-ElnY3p(:,t)+mean(log(predata(:,t+3))-ElnY3p(:,t))).^2-EvarlnY3p(:,t);  %3-year growth variance
                end
            end
        end
        for k=1:S
            ya=predata(:,t)./Errs(:,k,t);
            la=(predata(:,29+t)-predata(:,t))+ya;
            if model.slbar+model.clbar>0
                Prv(la>0,k)=logncdf((model.slbar+model.clbar)*ya(la>0)./la(la>0),0,(model.Varu).^(0.5));
                Prv(la<=0,k)=1;
            else
                Prv(la>0,k)=0;
                Prv(la<=0,k)=1-logncdf((model.slbar+model.clbar)*ya(la<=0)./la(la<=0),0,(model.Varu).^(0.5));
            end
        end
        Pr(:,t)=mean(Prv,2);
        devC(:,t)=(predata(:,33+t)-EClev(:,t));
        devD(:,t)=((predata(:,4+t)>1)-Ed(:,t));
        devI(:,t)=(predata(:,4+t)-EdIlev(:,t));
    end
    %now we construct remaining moments
    
    eps(:,4)=sum(devYvar1(:,2:4),2);  %1-year growth variance
    eps(:,5)=sum(devYvar2(:,2:3),2);  %2-year growth variance
    eps(:,6)=devYvar3(:,2);  %3-year growth variance
    eps(:,7)=sum((predata(:,27:30)-Pr(:,2:5)),2); %default moment
    eps(:,8)=sum(devC(:,2:5),2);
    eps(:,9)=sum(((devC(:,2:5)-mean(eps(:,8))).*log(predata(:,2:5))),2);
    eps(:,10)=sum(((devC(:,2:5)-mean(eps(:,8))).*predata(:,31:34)./predata(:,2:5)),2);
    eps(:,11)=sum(devD(:,2:5),2);
    eps(:,12)=sum(((devD(:,2:5)-mean(eps(:,11))).*log(predata(:,2:5))),2);
    eps(:,13)=sum(((devD(:,2:5)-mean(eps(:,11))).*predata(:,31:34)./predata(:,2:5)),2);
    eps(:,14)=sum(devI(:,2:5),2);
    eps(:,15)=sum(((devI(:,2:5)-mean(eps(:,14))).*log(predata(:,2:5))),2);
    eps(:,16)=sum(((devI(:,2:5)-mean(eps(:,14))).*predata(:,31:34)./predata(:,2:5)),2);
    for t=1:16
        eps(:,t)=eps(:,t)/sqrt(abs(var(eps(:,t))-mean(eps(:,t))^2));  
    end
end
summedeps=mean(eps,1)

%elapse=toc
