*This file uses the raw data in HHpaneldata.dta to create the summary data in Table2 (under the file Table2.log)
*It then follows the procedures explained in Section 4.1.1. to construct the data used in the rest of the paper,
*which is outputted to the file imputeddata.dta. It also creates several ASCII files for use in Matlab codes:
*Table3data.csv, Table5data.csv, and Section5_4_2.csv
 


set more off
set mem 200m
set matsize 200
!rm temp.dta yyears.dta transformed.dta
#delimit ;

use HHpaneldata.dta, clear;
g ifbinv=(fbinv>0);

g HH=1/invHH;
sort case_id year;
by case_id: g dly=log(nnetinc[_n+1]/nnetinc[_n]);
by case_id: g dlc=log(tc[_n+1]/tc[_n]);
sort year;
replace intst=. if year==1;
replace tc=. if year==1;

g llev=((totsv-allst)+nnetinc+intinc-intst);

log using Table2.log, replace;
summ nnetinc dly tc llev ifbinv fbinv defi allst intst totsvlag intinc madult fadult kids maleh educh ageh if year<=5, detail;
log close;

g lrat=((totsv-allst)+nnetinc+intinc-intst)/nnetinc;
g cy=tc/nnetinc;
g lc=log(tc);
g li=log(fbinv);
g ly=log(nnetinc);
g lint=log(intinc);
g ls=log(totsvlag);
g lst=log(allst);
g lintst=log(intst);

g yrchang=year*100+changwat;
save temp, replace;
sort case_id;

*now run regressions; 
*log income;
xtreg ly ib107o(149 527 553 607 627 627 649 653 707 727 749 753).yrchang ageh agehsq maleh madult fadult kids educh if year<=5, i(case_id) fe;

egen agehb1=mean(ageh) if e(sample);
egen agehb=mean(agehb1);
egen agehsqb1=mean(agehsq) if e(sample);
egen agehsqb=mean(agehsqb1);
egen educhb1=mean(educh) if e(sample);
egen educhb=mean(educhb1);
egen malehb1=mean(maleh) if e(sample);
egen malehb=mean(malehb1);
egen madultb1=mean(madult) if e(sample);
egen madultb=mean(madultb1);
egen fadultb1=mean(fadult) if e(sample);
egen fadultb=mean(fadultb1);
egen kidsb1=mean(kids) if e(sample);
egen kidsb=mean(kidsb1);


foreach i in 107 127 149 153 207 227 249 253 307 327 349 353 407 427 449 453 507 527 549 553 {;
	summ `i'.yrchang if e(sample);
	local mean`i'e = r(mean);
};


gen ch07h=`mean207e'*[#1]207.yrchang+`mean307e'*[#1]307.yrchang+`mean407e'*[#1]407.yrchang+`mean507e'*[#1]507.yrchang if e(sample);
gen ch27h=`mean127e'*[#1]127.yrchang+`mean227e'*[#1]227.yrchang+`mean327e'*[#1]327.yrchang+`mean427e'*[#1]427.yrchang+`mean527e'*[#1]527.yrchang if e(sample);
gen ch49h=`mean149e'*[#1]149.yrchang+`mean249e'*[#1]249.yrchang+`mean349e'*[#1]349.yrchang+`mean449e'*[#1]449.yrchang+`mean549e'*[#1]549.yrchang if e(sample);
gen ch53h=`mean153e'*[#1]153.yrchang+`mean253e'*[#1]253.yrchang+`mean353e'*[#1]353.yrchang+`mean453e'*[#1]453.yrchang+`mean553e'*[#1]553.yrchang if e(sample);
egen ch07=mean(ch07h);
egen ch27=mean(ch27h);
egen ch49=mean(ch49h);
egen ch53=mean(ch53h);

predict uy if e(sample), u;
sort case_id;
by case_id: egen ub1=mean(uy);
egen ub=mean(uy);
predict ey if e(sample), e;
replace ey=ly-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +107.yrchang*[#1]107.yrchang+127.yrchang*[#1]127.yrchang+149.yrchang*[#1]149.yrchang+153.yrchang*[#1]153.yrchang  
              +207.yrchang*[#1]207.yrchang+227.yrchang*[#1]227.yrchang+249.yrchang*[#1]249.yrchang+253.yrchang*[#1]253.yrchang
              +307.yrchang*[#1]307.yrchang+327.yrchang*[#1]327.yrchang+349.yrchang*[#1]349.yrchang+353.yrchang*[#1]353.yrchang
              +407.yrchang*[#1]407.yrchang+427.yrchang*[#1]427.yrchang+449.yrchang*[#1]449.yrchang+453.yrchang*[#1]453.yrchang
              +507.yrchang*[#1]507.yrchang+527.yrchang*[#1]527.yrchang+549.yrchang*[#1]549.yrchang+553.yrchang*[#1]553.yrchang)
		  if ey==. & year<=5;
replace ey=ly-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +607.yrchang*ch07+627.yrchang*ch27+649.yrchang*ch49+653.yrchang*ch53
              +707.yrchang*ch07+727.yrchang*ch27+749.yrchang*ch49+753.yrchang*ch53)
		  if year>5; 
g newly=[#1]_cons+ub+agehb*[#1]ageh+agehsqb*[#1]agehsq+educhb*[#1]educh+malehb*[#1]maleh+madultb*[#1]madult+fadultb*[#1]fadult+kidsb*[#1]kids
              +`mean107e'*[#1]107.yrchang+`mean127e'*[#1]127.yrchang+`mean149e'*[#1]149.yrchang+`mean153e'*[#1]153.yrchang  
              +`mean207e'*[#1]207.yrchang+`mean227e'*[#1]227.yrchang+`mean249e'*[#1]249.yrchang+`mean253e'*[#1]253.yrchang
              +`mean307e'*[#1]307.yrchang+`mean327e'*[#1]327.yrchang+`mean349e'*[#1]349.yrchang+`mean353e'*[#1]353.yrchang
              +`mean407e'*[#1]407.yrchang+`mean427e'*[#1]427.yrchang+`mean449e'*[#1]449.yrchang+`mean453e'*[#1]453.yrchang
              +`mean507e'*[#1]507.yrchang+`mean527e'*[#1]527.yrchang+`mean549e'*[#1]549.yrchang+`mean553e'*[#1]553.yrchang +ey;
drop agehb agehb1 agehsqb agehsqb1 educhb educhb1 malehb malehb1 madultb madultb1 fadultb fadultb1 kidsb kidsb1 ub ub1
      ch07 ch27 ch49 ch53 ch07h ch27h ch49h ch53h ey;  



xtreg lc ib107o(127 149 153 207 253 527 549 607 627 627 649 653 707 727 749 753).yrchang ageh agehsq maleh madult fadult kids educh if year<=5, i(case_id) fe;

egen agehb1=mean(ageh) if e(sample);
egen agehb=mean(agehb1);
egen agehsqb1=mean(agehsq) if e(sample);
egen agehsqb=mean(agehsqb1);
egen educhb1=mean(educh) if e(sample);
egen educhb=mean(educhb1);
egen malehb1=mean(maleh) if e(sample);
egen malehb=mean(malehb1);
egen madultb1=mean(madult) if e(sample);
egen madultb=mean(madultb1);
egen fadultb1=mean(fadult) if e(sample);
egen fadultb=mean(fadultb1);
egen kidsb1=mean(kids) if e(sample);
egen kidsb=mean(kidsb1);


foreach i in 127 149 153 207 227 249 253 307 327 349 353 407 427 449 453 507 527 549 553 {;
	summ `i'.yrchang if e(sample);
	local mean`i'e = r(mean);
};


gen ch07h=`mean207e'*[#1]207.yrchang+`mean307e'*[#1]307.yrchang+`mean407e'*[#1]407.yrchang+`mean507e'*[#1]507.yrchang if e(sample);
gen ch27h=`mean227e'*[#1]227.yrchang+`mean327e'*[#1]327.yrchang+`mean427e'*[#1]427.yrchang+`mean527e'*[#1]527.yrchang if e(sample);
gen ch49h=`mean249e'*[#1]249.yrchang+`mean349e'*[#1]349.yrchang+`mean449e'*[#1]449.yrchang+`mean549e'*[#1]549.yrchang if e(sample);
gen ch53h=`mean253e'*[#1]253.yrchang+`mean353e'*[#1]353.yrchang+`mean453e'*[#1]453.yrchang+`mean553e'*[#1]553.yrchang if e(sample);
egen ch07=mean(ch07h);
egen ch27=mean(ch27h);
egen ch49=mean(ch49h);
egen ch53=mean(ch53h);

predict uc if e(sample), u;
sort case_id;
by case_id: egen ub1=mean(uc);
egen ub=mean(uc);
predict ec if e(sample), e;
replace ec=lc-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +107.yrchang*[#1]107.yrchang+127.yrchang*[#1]127.yrchang+149.yrchang*[#1]149.yrchang+153.yrchang*[#1]153.yrchang  
              +207.yrchang*[#1]207.yrchang+227.yrchang*[#1]227.yrchang+249.yrchang*[#1]249.yrchang+253.yrchang*[#1]253.yrchang
              +307.yrchang*[#1]307.yrchang+327.yrchang*[#1]327.yrchang+349.yrchang*[#1]349.yrchang+353.yrchang*[#1]353.yrchang
              +407.yrchang*[#1]407.yrchang+427.yrchang*[#1]427.yrchang+449.yrchang*[#1]449.yrchang+453.yrchang*[#1]453.yrchang
              +507.yrchang*[#1]507.yrchang+527.yrchang*[#1]527.yrchang+549.yrchang*[#1]549.yrchang+553.yrchang*[#1]553.yrchang)
		  if ec==. & year<=5;
replace ec=lc-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +607.yrchang*ch07+627.yrchang*ch27+649.yrchang*ch49+653.yrchang*ch53
              +707.yrchang*ch07+727.yrchang*ch27+749.yrchang*ch49+753.yrchang*ch53)
		  if year>5; 
g newlc=[#1]_cons+ub+agehb*[#1]ageh+agehsqb*[#1]agehsq+educhb*[#1]educh+malehb*[#1]maleh+madultb*[#1]madult+fadultb*[#1]fadult+kidsb*[#1]kids
              +`mean107e'*[#1]107.yrchang+`mean127e'*[#1]127.yrchang+`mean149e'*[#1]149.yrchang+`mean153e'*[#1]153.yrchang  
              +`mean207e'*[#1]207.yrchang+`mean227e'*[#1]227.yrchang+`mean249e'*[#1]249.yrchang+`mean253e'*[#1]253.yrchang
              +`mean307e'*[#1]307.yrchang+`mean327e'*[#1]327.yrchang+`mean349e'*[#1]349.yrchang+`mean353e'*[#1]353.yrchang
              +`mean407e'*[#1]407.yrchang+`mean427e'*[#1]427.yrchang+`mean449e'*[#1]449.yrchang+`mean453e'*[#1]453.yrchang
              +`mean507e'*[#1]507.yrchang+`mean527e'*[#1]527.yrchang+`mean549e'*[#1]549.yrchang+`mean553e'*[#1]553.yrchang +ec;
drop agehb agehb1 agehsqb agehsqb1 educhb educhb1 malehb malehb1 madultb madultb1 fadultb fadultb1 kidsb kidsb1 ub ub1
      ch07 ch27 ch49 ch53 ch07h ch27h ch49h ch53h ec;  

xtreg lrat ib107o(127 149 153 207 253 527 549 607 627 627 649 653 707 727 749 753).yrchang ageh agehsq maleh madult fadult kids educh if year<=5, i(case_id) fe;

egen agehb1=mean(ageh) if e(sample);
egen agehb=mean(agehb1);
egen agehsqb1=mean(agehsq) if e(sample);
egen agehsqb=mean(agehsqb1);
egen educhb1=mean(educh) if e(sample);
egen educhb=mean(educhb1);
egen malehb1=mean(maleh) if e(sample);
egen malehb=mean(malehb1);
egen madultb1=mean(madult) if e(sample);
egen madultb=mean(madultb1);
egen fadultb1=mean(fadult) if e(sample);
egen fadultb=mean(fadultb1);
egen kidsb1=mean(kids) if e(sample);
egen kidsb=mean(kidsb1);


foreach i in 127 149 153 207 227 249 253 307 327 349 353 407 427 449 453 507 527 549 553 {;
	summ `i'.yrchang if e(sample);
	local mean`i'e = r(mean);
};


gen ch07h=`mean207e'*[#1]207.yrchang+`mean307e'*[#1]307.yrchang+`mean407e'*[#1]407.yrchang+`mean507e'*[#1]507.yrchang if e(sample);
gen ch27h=`mean227e'*[#1]227.yrchang+`mean327e'*[#1]327.yrchang+`mean427e'*[#1]427.yrchang+`mean527e'*[#1]527.yrchang if e(sample);
gen ch49h=`mean249e'*[#1]249.yrchang+`mean349e'*[#1]349.yrchang+`mean449e'*[#1]449.yrchang+`mean549e'*[#1]549.yrchang if e(sample);
gen ch53h=`mean253e'*[#1]253.yrchang+`mean353e'*[#1]353.yrchang+`mean453e'*[#1]453.yrchang+`mean553e'*[#1]553.yrchang if e(sample);
egen ch07=mean(ch07h);
egen ch27=mean(ch27h);
egen ch49=mean(ch49h);
egen ch53=mean(ch53h);

predict ulrat if e(sample), u;
sort case_id;
by case_id: egen ub1=mean(ulrat);
egen ub=mean(ulrat);
predict elrat if e(sample), e;
replace elrat=lrat-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +107.yrchang*[#1]107.yrchang+127.yrchang*[#1]127.yrchang+149.yrchang*[#1]149.yrchang+153.yrchang*[#1]153.yrchang  
              +207.yrchang*[#1]207.yrchang+227.yrchang*[#1]227.yrchang+249.yrchang*[#1]249.yrchang+253.yrchang*[#1]253.yrchang
              +307.yrchang*[#1]307.yrchang+327.yrchang*[#1]327.yrchang+349.yrchang*[#1]349.yrchang+353.yrchang*[#1]353.yrchang
              +407.yrchang*[#1]407.yrchang+427.yrchang*[#1]427.yrchang+449.yrchang*[#1]449.yrchang+453.yrchang*[#1]453.yrchang
              +507.yrchang*[#1]507.yrchang+527.yrchang*[#1]527.yrchang+549.yrchang*[#1]549.yrchang+553.yrchang*[#1]553.yrchang)
		  if elrat==. & year<=5;
replace elrat=lrat-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +607.yrchang*ch07+627.yrchang*ch27+649.yrchang*ch49+653.yrchang*ch53
              +707.yrchang*ch07+727.yrchang*ch27+749.yrchang*ch49+753.yrchang*ch53)
		  if year>5; 
g newlrat=[#1]_cons+ub+agehb*[#1]ageh+agehsqb*[#1]agehsq+educhb*[#1]educh+malehb*[#1]maleh+madultb*[#1]madult+fadultb*[#1]fadult+kidsb*[#1]kids
              +`mean107e'*[#1]107.yrchang+`mean127e'*[#1]127.yrchang+`mean149e'*[#1]149.yrchang+`mean153e'*[#1]153.yrchang  
              +`mean207e'*[#1]207.yrchang+`mean227e'*[#1]227.yrchang+`mean249e'*[#1]249.yrchang+`mean253e'*[#1]253.yrchang
              +`mean307e'*[#1]307.yrchang+`mean327e'*[#1]327.yrchang+`mean349e'*[#1]349.yrchang+`mean353e'*[#1]353.yrchang
              +`mean407e'*[#1]407.yrchang+`mean427e'*[#1]427.yrchang+`mean449e'*[#1]449.yrchang+`mean453e'*[#1]453.yrchang
              +`mean507e'*[#1]507.yrchang+`mean527e'*[#1]527.yrchang+`mean549e'*[#1]549.yrchang+`mean553e'*[#1]553.yrchang +elrat;
drop agehb agehb1 agehsqb agehsqb1 educhb educhb1 malehb malehb1 madultb madultb1 fadultb fadultb1 kidsb kidsb1 ub ub1
      ch07 ch27 ch49 ch53 ch07h ch27h ch49h ch53h elrat;  


xtreg defi ib107o(149 527 553 607 627 627 649 653 707 727 749 753).yrchang ageh agehsq maleh madult fadult kids educh if year<=5, i(case_id) fe;

egen agehb1=mean(ageh) if e(sample);
egen agehb=mean(agehb1);
egen agehsqb1=mean(agehsq) if e(sample);
egen agehsqb=mean(agehsqb1);
egen educhb1=mean(educh) if e(sample);
egen educhb=mean(educhb1);
egen malehb1=mean(maleh) if e(sample);
egen malehb=mean(malehb1);
egen madultb1=mean(madult) if e(sample);
egen madultb=mean(madultb1);
egen fadultb1=mean(fadult) if e(sample);
egen fadultb=mean(fadultb1);
egen kidsb1=mean(kids) if e(sample);
egen kidsb=mean(kidsb1);


foreach i in 127 149 153 207 227 249 253 307 327 349 353 407 427 449 453 507 527 549 553 {;
	summ `i'.yrchang if e(sample);
	local mean`i'e = r(mean);
};


gen ch07h=`mean207e'*[#1]207.yrchang+`mean307e'*[#1]307.yrchang+`mean407e'*[#1]407.yrchang+`mean507e'*[#1]507.yrchang if e(sample);
gen ch27h=`mean227e'*[#1]227.yrchang+`mean327e'*[#1]327.yrchang+`mean427e'*[#1]427.yrchang+`mean527e'*[#1]527.yrchang if e(sample);
gen ch49h=`mean249e'*[#1]249.yrchang+`mean349e'*[#1]349.yrchang+`mean449e'*[#1]449.yrchang+`mean549e'*[#1]549.yrchang if e(sample);
gen ch53h=`mean253e'*[#1]253.yrchang+`mean353e'*[#1]353.yrchang+`mean453e'*[#1]453.yrchang+`mean553e'*[#1]553.yrchang if e(sample);
egen ch07=mean(ch07h);
egen ch27=mean(ch27h);
egen ch49=mean(ch49h);
egen ch53=mean(ch53h);

predict udefi if e(sample), u;
sort case_id;
by case_id: egen ub1=mean(udefi);
egen ub=mean(udefi);
predict edefi if e(sample), e;
replace edefi=defi-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +107.yrchang*[#1]107.yrchang+127.yrchang*[#1]127.yrchang+149.yrchang*[#1]149.yrchang+153.yrchang*[#1]153.yrchang  
              +207.yrchang*[#1]207.yrchang+227.yrchang*[#1]227.yrchang+249.yrchang*[#1]249.yrchang+253.yrchang*[#1]253.yrchang
              +307.yrchang*[#1]307.yrchang+327.yrchang*[#1]327.yrchang+349.yrchang*[#1]349.yrchang+353.yrchang*[#1]353.yrchang
              +407.yrchang*[#1]407.yrchang+427.yrchang*[#1]427.yrchang+449.yrchang*[#1]449.yrchang+453.yrchang*[#1]453.yrchang
              +507.yrchang*[#1]507.yrchang+527.yrchang*[#1]527.yrchang+549.yrchang*[#1]549.yrchang+553.yrchang*[#1]553.yrchang)
		  if edefi==. & year<=5;
replace edefi=defi-([#1]_cons+ub1+ageh*[#1]ageh+agehsq*[#1]agehsq+educh*[#1]educh+maleh*[#1]maleh+madult*[#1]madult+fadult*[#1]fadult+kids*[#1]kids
              +607.yrchang*ch07+627.yrchang*ch27+649.yrchang*ch49+653.yrchang*ch53
              +707.yrchang*ch07+727.yrchang*ch27+749.yrchang*ch49+753.yrchang*ch53)
		  if year>5; 
g newdefi=[#1]_cons+ub+agehb*[#1]ageh+agehsqb*[#1]agehsq+educhb*[#1]educh+malehb*[#1]maleh+madultb*[#1]madult+fadultb*[#1]fadult+kidsb*[#1]kids
              +`mean107e'*[#1]107.yrchang+`mean127e'*[#1]127.yrchang+`mean149e'*[#1]149.yrchang+`mean153e'*[#1]153.yrchang  
              +`mean207e'*[#1]207.yrchang+`mean227e'*[#1]227.yrchang+`mean249e'*[#1]249.yrchang+`mean253e'*[#1]253.yrchang
              +`mean307e'*[#1]307.yrchang+`mean327e'*[#1]327.yrchang+`mean349e'*[#1]349.yrchang+`mean353e'*[#1]353.yrchang
              +`mean407e'*[#1]407.yrchang+`mean427e'*[#1]427.yrchang+`mean449e'*[#1]449.yrchang+`mean453e'*[#1]453.yrchang
              +`mean507e'*[#1]507.yrchang+`mean527e'*[#1]527.yrchang+`mean549e'*[#1]549.yrchang+`mean553e'*[#1]553.yrchang +edefi;
drop agehb agehb1 agehsqb agehsqb1 educhb educhb1 malehb malehb1 madultb madultb1 fadultb fadultb1 kidsb kidsb1 ub ub1
      ch07 ch27 ch49 ch53 ch07h ch27h ch49h ch53h edefi;  


*compare series, add back in growth rates, and rescale adjusted data to match means;
summ cy newlc lrat newlrat ly newly defi newdefi;
sort case_id year;
by case_id: g dnewly=newly[_n+1]-newly[_n];
by case_id: g dnewlc=newlc[_n+1]-newlc[_n];
sort year;
by year: summ nnetinc newly ly;

egen oldmeandlyb=mean(dly) if year<=4;
egen oldmeandly=mean(oldmeandlyb);
egen newmeandlyb=mean(dnewly) if year<=4;
egen newmeandly=mean(newmeandlyb);
replace newly=newly+(year-3)*(oldmeandly-newmeandly);
sort case_id year;
by case_id: replace dnewly=newly[_n+1]-newly[_n];

egen oldmeandlcb=mean(dlc) if year<=4;
egen oldmeandlc=mean(oldmeandlcb);
egen newmeandlcb=mean(dnewlc) if year<=4;
egen newmeandlc=mean(newmeandlcb);
replace newlc=newlc+(year-3)*(oldmeandlc-newmeandlc);
sort case_id year;
by case_id: replace dnewlc=newlc[_n+1]-newlc[_n];

g y=exp(newly);

egen oldmeanyb=mean(nnetinc) if year<=5;
egen oldmeany=mean(oldmeanyb);
egen newmeanyb=mean(y) if year<=5;
egen newmeany=mean(newmeanyb);
replace y=y*oldmeany/newmeany;
g c=exp(newlc);
egen oldmeancb=mean(tc) if year<=5;
egen oldmeanc=mean(oldmeancb);
egen newmeancb=mean(c) if year<=5;
egen newmeanc=mean(newmeancb);
replace c=c*oldmeanc/newmeanc;

*construct new liquidity series;
g l=newlrat*y;
egen oldmeanlb=mean(llev) if year<=5;
egen oldmeanl=mean(oldmeanlb);
egen newmeanlb=mean(l) if year<=5;
egen newmeanl=mean(newmeanlb);
replace l=l*oldmeanl/newmeanl;

*construct new investment series by rescaling;
g i=fbinv*y/nnetinc;
egen oldmeanib=mean(fbinv) if year<=5;
egen oldmeani=mean(oldmeanib);
egen newmeanib=mean(i) if year<=5;
egen newmeani=mean(newmeanib);
replace i=i*oldmeani/newmeani;

g iind= (i>0);

*here we just compare the oldseries with the new;
summ c tc i fbinv iind dnewly dly y nnetinc defi newdefi lrat newlrat if year<=5, detail;
summ dnewly dly if year<=4, detail;



replace i=1 if i==0;
keep c i y intinc totsvlag intst allst l llev nnetinc vfst defi newdefi HH case_id changwat amphoe tambon village year;
sort case_id year;
save imputeddata, replace;

reshape wide c i y intinc totsvlag intst allst l llev nnetinc vfst defi newdefi HH, i(case_id changwat amphoe tambon village) j(year);
*here we create the file for the pre-sample estimation;
outsheet y1 y2 y3 y4 y5 i1 i2 i3 i4 i5 intinc1 intinc2 intinc3 intinc4 totsvlag2 totsvlag3 totsvlag4 totsvlag5 intst2 intst3 intst4 intst5 allst2 allst3 allst4 allst5 newdefi2 newdefi3 newdefi4 newdefi5 l2 l3 l4 l5 c2 c3 c4 c5 using Table3data.csv, comma nonames replace;

egen v=group(changwat amphoe tambon village);
sort v;
keep if y1~=.& y2~=. & y3~=. & y4~=. & y5~=. & y6~=. & y7~=. & i1~=. & i2~=. & i3~=. & i4~=. & i5~=. & i6~=. & i7~=. & newdefi2~=. & newdefi3~=. & newdefi4~=. & newdefi5~=. & newdefi6~=. & newdefi7~=. & l5~=. & c2~=. & c3~=. & c4~=. & c5~=. & c6~=. & c7~=. & HH6~=. & v~=.;
outsheet y1 y2 y3 y4 y5 y6 y7 i1 i2 i3 i4 i5 i6 i7 newdefi2 newdefi3 newdefi4 newdefi5 newdefi6 newdefi7  l2 l3 l4 l5 l6 l7 c2 c3 c4 c5 c6 c7 v HH6 using Table5data.csv, comma nonames replace;
outsheet y1 y2 y3 y4 y5 y6 y7 i1 i2 i3 i4 i5 i6 i7 intinc1 intinc2 intinc3 intinc4 intinc5 intinc6 totsvlag2 totsvlag3 totsvlag4 totsvlag5 totsvlag6 totsvlag7 intst2 intst3 intst4 intst5 intst6 intst7 allst2 allst3 allst4 allst5 allst6 allst7 newdefi2 newdefi3 newdefi4 newdefi5 newdefi6 newdefi7 l2 l3 l4 l5 l6 l7 c2 c3 c4 c5 c6 c7  v HH6 using Section5_4_2data.csv, comma nonames replace;

